==> qore-0.8.12.3.tar.bz2: qore-0.8.12.3/docs/modules/FixedLengthUtil/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore FixedLengthUtil Module Reference", "index.html", [
    [ "FixedLengthUtil Module", "index.html", [
      [ "Introduction to the FixedLengthUtil Module", "index.html#fixedlengthutilintro", null ],
      [ "Global Options", "index.html#fixedlengthglobals", null ],
      [ "Specification Hash", "index.html#fixedlengthspec", [
        [ "Record Description Hash", "index.html#fixedlengthspecrecordhash", null ],
        [ "Field Specification Hash", "index.html#fixedlengthspecrow", null ],
        [ "Field Data Types", "index.html#fixedlengthspectypes", null ]
      ] ],
      [ "Record Type Resolution", "index.html#fixedlengthrecordtyperesolution", null ],
      [ "Fixed Length Data Format", "index.html#fixedlengthformat", null ],
      [ "Release Notes", "index.html#fixedlengthutil_relnotes", [
        [ "Version 1.0", "index.html#fixedlengthutil_v1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.8.13.2.tar.bz2: qore-0.8.13.2/docs/modules/FixedLengthUtil/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore FixedLengthUtil Module Reference", "index.html", [
    [ "FixedLengthUtil Module", "index.html", [
      [ "Introduction to the FixedLengthUtil Module", "index.html#fixedlengthutilintro", null ],
      [ "Global Options", "index.html#fixedlengthglobals", null ],
      [ "Specification Hash", "index.html#fixedlengthspec", [
        [ "Record Description Hash", "index.html#fixedlengthspecrecordhash", null ],
        [ "Field Specification Hash", "index.html#fixedlengthspecrow", null ],
        [ "Field Data Types", "index.html#fixedlengthspectypes", null ]
      ] ],
      [ "Record Type Resolution", "index.html#fixedlengthrecordtyperesolution", null ],
      [ "Fixed Length Data Format", "index.html#fixedlengthformat", null ],
      [ "Release Notes", "index.html#fixedlengthutil_relnotes", [
        [ "Version 1.1", "index.html#fixedlengthutil_v1_1", null ],
        [ "Version 1.0.1", "index.html#fixedlengthutil_v1_0_1", null ],
        [ "Version 1.0", "index.html#fixedlengthutil_v1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
